+ fix-broken-dubious-driver-suspend-methods.patch added to -mm tree

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The patch titled

     fix broken/dubious driver suspend() methods

has been added to the -mm tree.  Its filename is

     fix-broken-dubious-driver-suspend-methods.patch

See http://www.zip.com.au/~akpm/linux/patches/stuff/added-to-mm.txt to find
out what to do about this

------------------------------------------------------
Subject: fix broken/dubious driver suspend() methods
From: David Brownell <david-b@xxxxxxxxxxx>


Small driver suspend() fixes in preparation for the PRETHAW events:

 - Only compare message events for equality against PM_EVENT_* codes;
   not against integers, or using greater/less-than comparisons.
   (PM_EVENT_* should really become a __bitwise thing.)

 - Explicitly test for SUSPEND events (rather than not-something-else)
   before suspending devices.

 - Removes more of the confusion between a pm_message_t (wraps event code)
   and a "state" ... suspend() originally took a target system state.

These updates are correct and appropriate even without new PM_EVENT codes.

Signed-off-by: David Brownell <dbrownell@xxxxxxxxxxxxxxxxxxxxx>
Acked-by: Pavel Machek <pavel@xxxxxx>
Cc: Greg KH <greg@xxxxxxxxx>
Cc: Jeff Garzik <jeff@xxxxxxxxxx>
Cc: Tejun Heo <htejun@xxxxxxxxx>
Cc: Paul Mackerras <paulus@xxxxxxxxx>
Cc: Benjamin Herrenschmidt <benh@xxxxxxxxxxxxxxxxxxx>
Signed-off-by: Andrew Morton <akpm@xxxxxxxx>
---

 drivers/ide/ppc/pmac.c                  |   14 ++++++++------
 drivers/media/dvb/cinergyT2/cinergyT2.c |    2 +-
 drivers/scsi/libata-core.c              |    6 +++---
 drivers/scsi/mesh.c                     |    7 ++++---
 4 files changed, 16 insertions(+), 13 deletions(-)

diff -puN drivers/ide/ppc/pmac.c~fix-broken-dubious-driver-suspend-methods drivers/ide/ppc/pmac.c
--- devel/drivers/ide/ppc/pmac.c~fix-broken-dubious-driver-suspend-methods	2006-06-07 23:44:42.000000000 -0700
+++ devel-akpm/drivers/ide/ppc/pmac.c	2006-06-07 23:44:42.000000000 -0700
@@ -1495,15 +1495,16 @@ pmac_ide_macio_attach(struct macio_dev *
 }
 
 static int
-pmac_ide_macio_suspend(struct macio_dev *mdev, pm_message_t state)
+pmac_ide_macio_suspend(struct macio_dev *mdev, pm_message_t mesg)
 {
 	ide_hwif_t	*hwif = (ide_hwif_t *)dev_get_drvdata(&mdev->ofdev.dev);
 	int		rc = 0;
 
-	if (state.event != mdev->ofdev.dev.power.power_state.event && state.event >= PM_EVENT_SUSPEND) {
+	if (mesg.event != mdev->ofdev.dev.power.power_state.event
+			&& mesg.event == PM_EVENT_SUSPEND) {
 		rc = pmac_ide_do_suspend(hwif);
 		if (rc == 0)
-			mdev->ofdev.dev.power.power_state = state;
+			mdev->ofdev.dev.power.power_state = mesg;
 	}
 
 	return rc;
@@ -1599,15 +1600,16 @@ pmac_ide_pci_attach(struct pci_dev *pdev
 }
 
 static int
-pmac_ide_pci_suspend(struct pci_dev *pdev, pm_message_t state)
+pmac_ide_pci_suspend(struct pci_dev *pdev, pm_message_t mesg)
 {
 	ide_hwif_t	*hwif = (ide_hwif_t *)pci_get_drvdata(pdev);
 	int		rc = 0;
 	
-	if (state.event != pdev->dev.power.power_state.event && state.event >= 2) {
+	if (mesg.event != pdev->dev.power.power_state.event
+			&& mesg.event == PM_EVENT_SUSPEND) {
 		rc = pmac_ide_do_suspend(hwif);
 		if (rc == 0)
-			pdev->dev.power.power_state = state;
+			pdev->dev.power.power_state = mesg;
 	}
 
 	return rc;
diff -puN drivers/media/dvb/cinergyT2/cinergyT2.c~fix-broken-dubious-driver-suspend-methods drivers/media/dvb/cinergyT2/cinergyT2.c
--- devel/drivers/media/dvb/cinergyT2/cinergyT2.c~fix-broken-dubious-driver-suspend-methods	2006-06-07 23:44:42.000000000 -0700
+++ devel-akpm/drivers/media/dvb/cinergyT2/cinergyT2.c	2006-06-07 23:44:42.000000000 -0700
@@ -978,7 +978,7 @@ static int cinergyt2_suspend (struct usb
 	if (cinergyt2->disconnect_pending || mutex_lock_interruptible(&cinergyt2->sem))
 		return -ERESTARTSYS;
 
-	if (state.event > PM_EVENT_ON) {
+	if (1) {
 		struct cinergyt2 *cinergyt2 = usb_get_intfdata (intf);
 
 		cinergyt2_suspend_rc(cinergyt2);
diff -puN drivers/scsi/mesh.c~fix-broken-dubious-driver-suspend-methods drivers/scsi/mesh.c
--- devel/drivers/scsi/mesh.c~fix-broken-dubious-driver-suspend-methods	2006-06-07 23:44:42.000000000 -0700
+++ devel-akpm/drivers/scsi/mesh.c	2006-06-07 23:44:42.000000000 -0700
@@ -1761,12 +1761,13 @@ static void set_mesh_power(struct mesh_s
 
 
 #ifdef CONFIG_PM
-static int mesh_suspend(struct macio_dev *mdev, pm_message_t state)
+static int mesh_suspend(struct macio_dev *mdev, pm_message_t mesg)
 {
 	struct mesh_state *ms = (struct mesh_state *)macio_get_drvdata(mdev);
 	unsigned long flags;
 
-	if (state.event == mdev->ofdev.dev.power.power_state.event || state.event < 2)
+	if (mesg.event == mdev->ofdev.dev.power.power_state.event
+			|| mesg.event != PM_EVENT_SUSPEND)
 		return 0;
 
 	scsi_block_requests(ms->host);
@@ -1781,7 +1782,7 @@ static int mesh_suspend(struct macio_dev
 	disable_irq(ms->meshintr);
 	set_mesh_power(ms, 0);
 
-	mdev->ofdev.dev.power.power_state = state;
+	mdev->ofdev.dev.power.power_state = mesg;
 
 	return 0;
 }
_

Patches currently in -mm which might be from david-b@xxxxxxxxxxx are

git-pcmcia.patch
rtc-framework-driver-for-ds1307-and-similar-rtc-chips.patch
random-remove-bogus-sa_sample_random-from-at91-compact-flash-driver.patch
fix-broken-dubious-driver-suspend-methods.patch

-
To unsubscribe from this list: send the line "unsubscribe mm-commits" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Kernel Newbies FAQ]     [Kernel Archive]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [Bugtraq]     [Photo]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux
diff -puN drivers/scsi/libata-core.c~fix-broken-dubious-driver-suspend-methods drivers/scsi/libata-core.c
--- devel/drivers/scsi/libata-core.c~fix-broken-dubious-driver-suspend-methods	2006-06-07 23:44:42.000000000 -0700
+++ devel-akpm/drivers/scsi/libata-core.c	2006-06-07 23:46:23.000000000 -0700
@@ -5043,12 +5043,12 @@ int ata_device_resume(struct ata_device 
 /**
  *	ata_device_suspend - prepare a device for suspend
  *	@dev: the device to suspend
  *	@state: target power management state
  *
  *	Flush the cache on the drive, if appropriate, then issue a
  *	standbynow command.
  */
-int ata_device_suspend(struct ata_device *dev, pm_message_t state)
+int ata_device_suspend(struct ata_device *dev, pm_message_t mesg)
 {
 	struct ata_port *ap = dev->ap;
 
@@ -5057,7 +5057,7 @@ int ata_device_suspend(struct ata_device
 	if (dev->class == ATA_DEV_ATA)
 		ata_flush_cache(dev);
 
-	if (state.event != PM_EVENT_FREEZE)
+	if (mesg.event == PM_EVENT_SUSPEND)
 		ata_standby_drive(dev);
 	ap->flags |= ATA_FLAG_SUSPENDED;
 	return 0;
@@ -5043,12 +5043,12 @@ int ata_device_resume(struct ata_device 
  *	ata_device_suspend - prepare a device for suspend
  *	@dev: the device to suspend
- *	@state: target power management state
+ *	@mesg: power management request
  *
  *	Flush the cache on the drive, if appropriate, then issue a